# INUMET API

INUMET Api wrapper for python

## Installation

```console
$ pip install inumet_api
```

## Example

```py
# import the module
from inumet_api import INUMET

print(INUMET().estado_actual())
```